@@ -21,6 +21,7 @@ else:
 
 __all__ = (
     "CompressionFormatType",
+    "DatabaseOutputModeType",
     "EncryptionModeType",
     "InputFormatType",
     "JobRunStateType",
@@ -47,6 +48,7 @@ __all__ = (
 CompressionFormatType = Literal[
     "BROTLI", "BZIP2", "DEFLATE", "GZIP", "LZ4", "LZO", "SNAPPY", "ZLIB", "ZSTD"
 ]
+DatabaseOutputModeType = Literal["NEW_TABLE"]
 EncryptionModeType = Literal["SSE-KMS", "SSE-S3"]
 InputFormatType = Literal["CSV", "EXCEL", "JSON", "PARQUET"]
 JobRunStateType = Literal[
